#!/usr/bin/env python
# -*- coding:UTF-8 -*-
"""
    This file shows how to use images as button.
    It is part of a RackToolChanger I made

    Copyright 2019 Norbert Schechner
    nieson@web.de

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
import gtk                      # needed to get access to the widgets
import os                       # needed to get the paths
import hal                      # base hal class to react to hal signals
import hal_glib                 # needed to make our own hal pins

CONFIGPATH = os.environ['CONFIG_DIR']
IMAGEDIR = os.path.join(CONFIGPATH, "IMAGES")
IMAGE_WIDTH = 120
IMAGE_HEIGHT = 60

class HandlerClass:
    def __init__(self, halcomp,builder,useropts):

        self.halcomp = halcomp
        self.builder = builder

        self.tbl_tools = self.builder.get_object('tbl_tools')
        self.lbl_info = self.builder.get_object('lbl_info')

        # we want to create our own hal pin
        self._make_hal_pin()

        # set up a reference to an pixbuffer object for loaded tool
        self.pixbuf_loaded = gtk.gdk.pixbuf_new_from_file_at_size(os.path.join(IMAGEDIR, 
                                                                 'TC_loaded.png'), IMAGE_WIDTH, IMAGE_HEIGHT)    

        # set up a reference to an pixbuffer object for empty pocket
        self.pixbuf_empty = gtk.gdk.pixbuf_new_from_file_at_size(os.path.join(IMAGEDIR, 
                                                                 'TC_empty.png'), IMAGE_WIDTH, IMAGE_HEIGHT)


        eventbox = gtk.EventBox()
        eventbox.set_name('Image_Button_1')
        self.image = gtk.Image()
        self.image.set_from_pixbuf(self.pixbuf_empty)
        self.image.set_name('imgage_empty')
        eventbox.add(self.image)
        eventbox.connect("button_press_event", self.on_evb_button_press_event)
        self.tbl_tools.attach(eventbox, 0, 1, 0 ,1 , gtk.SHRINK, gtk.EXPAND)
        self.tbl_tools.show_all()
        
    def _make_hal_pin(self):
        # make the hal pin
        pin = self.halcomp.newpin("hal_pin_1", hal.HAL_BIT, hal.HAL_IN)
        hal_glib.GPin(pin).connect("value_changed", self._on_hal_pin_changed)


    def on_evb_button_press_event(self, widget, event):
        message = "I received a click\n from eventbox\n".format(widget.name)
        if self.image.get_pixbuf() == self.pixbuf_empty:
            self.image.set_from_pixbuf(self.pixbuf_loaded)
            message += "Image was empty"
        else:
            self.image.set_from_pixbuf(self.pixbuf_empty)
            message += "Image was loaded"
        print(message)
        self.lbl_info.set_label(message)
        
    def _on_hal_pin_changed(self,pin):
        message = "I received a signal\n from hal pin\n".format(pin.name)
        message += "Pin has changed to {0}".format(pin.get())
        if pin.get():
            self.image.set_from_pixbuf(self.pixbuf_loaded)
        else:
            self.image.set_from_pixbuf(self.pixbuf_empty)
        self.lbl_info.set_label(message)

# boiler code
def get_handlers(halcomp,builder,useropts):
    return [HandlerClass(halcomp,builder,useropts)]
